#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-IX5saME2setFmvdQdT6ezQ
key:                  tasty-smallcheck-0.8.2-IX5saME2setFmvdQdT6ezQ
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  2dfb4251365098576479f72afa9bbd04
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-8.10.5/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/tasty-smallcheck-0.8.2
hs-libraries:         HStasty-smallcheck-0.8.2-IX5saME2setFmvdQdT6ezQ
depends:
    base-4.14.2.0 optparse-applicative-0.16.1.0-ARX6qDeExVWDKYrQ55nL8e
    smallcheck-1.2.1-Cpn9B07vHfB1r0zOWeWxAg
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV
    tasty-1.4.1-o6GqK7uhQW6VZVrPJnWQG

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

